@@ -52,6 +52,7 @@ package com.openexchange.datamining;
 import java.math.BigInteger;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
+import java.util.Map.Entry;
 
 /**
  * {@link Questions}
@@ -178,8 +179,6 @@ public class Questions {
 
     public static final String AVERAGE_DOCUMENT_SIZE = "averageDocumentSize";
 
-
-
     protected static void reportNumberOfUsers() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS);
@@ -187,38 +186,45 @@ public class Questions {
             BigInteger count = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS, count.toString());
         } catch (Exception e) {
+            System.out.println(e.getMessage());
         }
     }
 
     protected static void reportNumberOfUsersWithEventsInPrivateCalendar() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WITH_EVENTS_IN_PRIVATE_CALENDAR);
-            String sql = "select count(distinct created_from, cid) from prg_dates";
+            String sql = "SELECT COUNT(DISTINCT cid, user) FROM calendar_event WHERE account=0 AND folder IS NULL;";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WITH_EVENTS_IN_PRIVATE_CALENDAR, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
+    private static void handleError(Exception e) {
+        //TODO properly handle errors
+        System.out.println("Error : " + e.getMessage());
+    }
+
     protected static void reportNumberOfUsersWithEventsInPrivateCalendarThatAreInTheFutureAndAreNotYearlySeries() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WITH_EVENTS_IN_PRIVATE_CALENDAR_THAT_ARE_IN_THE_FUTURE_AND_ARE_NOT_YEARLY_SERIES);
-            String sql = "SELECT count(distinct created_from, cid) FROM prg_dates WHERE timestampfield02 > now() AND ((field06 NOT LIKE \"t|4%\" AND field06 NOT LIKE \"t|6%\") OR field06 IS NULL);";
+            String sql = "SELECT COUNT(DISTINCT cid, user) FROM calendar_event WHERE account=0 AND start > NOW() AND folder IS NULL AND (rrule IS NULL OR rrule NOT LIKE '%FREQ=YEARLY%');";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
-            Datamining.report(
-                NUMBER_OF_USERS_WITH_EVENTS_IN_PRIVATE_CALENDAR_THAT_ARE_IN_THE_FUTURE_AND_ARE_NOT_YEARLY_SERIES,
-                numberOfUsers.toString());
+            Datamining.report(NUMBER_OF_USERS_WITH_EVENTS_IN_PRIVATE_CALENDAR_THAT_ARE_IN_THE_FUTURE_AND_ARE_NOT_YEARLY_SERIES, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoChangedTheirCalendarInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CALENDAR_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_dates WHERE DATE(FROM_UNIXTIME(SUBSTRING(CAST(changing_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT cid, user) FROM calendar_event WHERE account=0 AND timestamp>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CALENDAR_IN_THE_LAST30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -229,26 +235,29 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_NEW_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfChangedInfostoreObjectsInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_CHANGED_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT infostore_id, cid) FROM infostore_document WHERE DATE(FROM_UNIXTIME(SUBSTRING(CAST(creating_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW();";
+            String sql = "SELECT count(DISTINCT infostore_id, cid) FROM infostore_document WHERE creating_date>= " + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_CHANGED_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWithNewInfostoreObjectsInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WITH_NEW_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT created_by, cid) FROM infostore_document WHERE DATE(FROM_UNIXTIME(SUBSTRING(CAST(creating_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT created_by, cid) FROM infostore_document WHERE creating_date>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WITH_NEW_INFOSTORE_OBJECTS_IN_THE_LAST30_DAYS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -259,6 +268,7 @@ public class Questions {
             BigInteger numberOfContacts = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_CONTACTS, numberOfContacts.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -269,16 +279,18 @@ public class Questions {
             BigInteger numberOfContacts = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USER_CREATED_CONTACTS, numberOfContacts.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfAppointments() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_APPOINTMENTS);
-            String sql = "SELECT count(*) FROM prg_dates;";
+            String sql = "SELECT count(*) FROM calendar_event WHERE account=0;";
             BigInteger numberOfAppointments = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_APPOINTMENTS, numberOfAppointments.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -289,6 +301,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_TASKS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -299,6 +312,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_DOCUMENTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -309,6 +323,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_HAVE_CONTACTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -319,26 +334,31 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CREATED_CONTACTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportMaximumNumberOfContactsForOneUser() {
         try {
             Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER);
+            // GROUP BY CLAUSE: ensure ONLY_FULL_GROUP_BY compatibility
             String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_contacts WHERE userid IS NULL GROUP BY cid, created_from) AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
             Datamining.report(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportMaximumNumberOfCreatedAppointmentsForOneUser() {
         try {
             Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_APPOINTMENTS_FOR_ONE_USER);
-            String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_dates) AS x;";
+            // GROUP BY CLAUSE: ensure ONLY_FULL_GROUP_BY compatibility
+            String sql = "SELECT MAX(count) FROM (SELECT COUNT(*) AS count FROM calendar_event WHERE account=0 GROUP BY cid, createdBy) AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
             Datamining.report(MAXIMUM_NUMBER_OF_CREATED_APPOINTMENTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -349,6 +369,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
             Datamining.report(MAXIMUM_NUMBER_OF_CREATED_DOCUMENTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -359,26 +380,30 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
             Datamining.report(MAXIMUM_NUMBER_OF_CREATED_TASKS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportMaximumNumberOfCreatedContactsForOneUser() {
         try {
             Datamining.allTheQuestions.add(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER);
+            // GROUP BY CLAUSE: ensure ONLY_FULL_GROUP_BY compatibility
             String sql = "SELECT MAX(count) FROM (SELECT cid, created_from, count(*) AS count FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL GROUP BY cid, created_from) AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.maximumForAllSchemata(sql);
             Datamining.report(MAXIMUM_NUMBER_OF_CREATED_CONTACTS_FOR_ONE_USER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoCreatedAppointments() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_dates;";
+            String sql = "SELECT COUNT(DISTINCT cid, createdBy) FROM calendar_event WHERE account=0;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -389,6 +414,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CREATED_TASKS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -399,16 +425,18 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoChangedTheirContactsInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CONTACTS_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL AND (DATE(FROM_UNIXTIME(SUBSTRING(CAST(changing_date AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW());";
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM prg_contacts WHERE userid IS NULL AND field02 IS NOT NULL AND field03 IS NOT NULL AND changing_date>= " + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CHANGED_THEIR_CONTACTS_IN_THE_LAST30_DAYS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -426,28 +454,26 @@ public class Questions {
                     Datamining.allTheQuestions.add("numberOfDocumentsBetween" + Tools.humanReadableBytes(size1[i]) + "And" + Tools.humanReadableBytes(size2[i]));
                     String sql = "SELECT COUNT(DISTINCT infostore.cid, infostore.id, infostore.version) FROM infostore LEFT OUTER JOIN infostore_document " + "ON infostore.cid = infostore_document.cid AND infostore.id = infostore_document.infostore_id " + "AND infostore.version = infostore_document.version_number WHERE infostore_document.file_size BETWEEN " + size1[i] + " AND " + size2[i];
                     BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
-                    Datamining.report(
-                        "numberOfDocumentsBetween" + Tools.humanReadableBytes(size1[i]) + "And" + Tools.humanReadableBytes(size2[i]),
-                        numberOfInfostoreObjects.toString());
+                    Datamining.report("numberOfDocumentsBetween" + Tools.humanReadableBytes(size1[i]) + "And" + Tools.humanReadableBytes(size2[i]), numberOfInfostoreObjects.toString());
                 }
             } else {
                 System.out.println("Error : Ranges in reportSliceAndDiceOnDocumentSize are not equal");
             }
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportSliceAndDiceOnDraftMailSize() {
         try {
-            LinkedHashMap<Integer, Integer> dms = Datamining.draftMailOverAllSchemata(new int[]{5000,10000,500000});
-            int ll=1;
-            for(final Integer key : dms.keySet() ) {
-                Datamining.report(
-                    "draftMailSizeBetween" + Tools.humanReadableBytes(""+ll) + "And" + Tools.humanReadableBytes(""+key),
-                    dms.get(key).toString());
-                ll=key;
+            LinkedHashMap<Integer, Integer> dms = Datamining.draftMailOverAllSchemata(new int[] { 5000, 10000, 500000 });
+            int ll = 1;
+            for (final Entry<Integer, Integer> entry : dms.entrySet()) {
+                Datamining.report("draftMailSizeBetween" + Tools.humanReadableBytes("" + ll) + "And" + Tools.humanReadableBytes("" + entry.getKey()), Integer.toString(entry.getValue() == null ? 0 : entry.getValue()));
+                ll = entry.getKey();
             }
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -455,15 +481,16 @@ public class Questions {
         try {
             int MAXEXT = 5;
             HashMap<Integer, Integer> eaos = Datamining.externalAccountsOverAllSchemata(MAXEXT);
-            for(final Integer key : eaos.keySet() ) {
-                Datamining.report("usersHaving" + (key < MAXEXT ? key : "MoreOrEqual" + key) + "ExternalAccounts", eaos.get(key).toString());
+            for (final Entry<Integer, Integer> entry : eaos.entrySet()) {
+                Datamining.report("usersHaving" + (entry.getKey() < MAXEXT ? entry.getKey() : "MoreOrEqual" + entry.getKey()) + "ExternalAccounts", Integer.toString(entry.getValue() == null ? 0 : entry.getValue()));
             }
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportAverageDocumentSize() {
-    	try {
+        try {
             Datamining.allTheQuestions.add(AVERAGE_DOCUMENT_SIZE);
 
             String sql = "SELECT AVG(file_size) FROM infostore_document;";
@@ -472,6 +499,7 @@ public class Questions {
 
             Datamining.report(AVERAGE_DOCUMENT_SIZE, Tools.humanReadableBytes(Integer.toString(resultInt)));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -485,10 +513,9 @@ public class Questions {
             float numberOfContacts = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_CONTACTS));
             float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_HAVE_CONTACTS));
 
-            Datamining.report(
-                AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CONTACTS_AT_ALL,
-                Float.toString(numberOfContacts / numberOfUsers));
+            Datamining.report(AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CONTACTS_AT_ALL, Float.toString(numberOfContacts / numberOfUsers));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -502,10 +529,9 @@ public class Questions {
             float numberOfContacts = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USER_CREATED_CONTACTS));
             float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_CONTACTS));
 
-            Datamining.report(
-                AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CREATED_CONTACTS,
-                Float.toString(numberOfContacts / numberOfUsers));
+            Datamining.report(AVERAGE_NUMBER_OF_CONTACTS_PER_USER_WHO_HAS_CREATED_CONTACTS, Float.toString(numberOfContacts / numberOfUsers));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -516,10 +542,9 @@ public class Questions {
             float numberOfAppointments = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_APPOINTMENTS));
             float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_APPOINTMENTS));
 
-            Datamining.report(
-                AVERAGE_NUMBER_OF_APPOINTMENTS_PER_USER_WHO_HAS_APPOINTMENTS_AT_ALL,
-                Float.toString(numberOfAppointments / numberOfUsers));
+            Datamining.report(AVERAGE_NUMBER_OF_APPOINTMENTS_PER_USER_WHO_HAS_APPOINTMENTS_AT_ALL, Float.toString(numberOfAppointments / numberOfUsers));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -530,10 +555,9 @@ public class Questions {
             float numberOfTasks = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_TASKS));
             float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_TASKS));
 
-            Datamining.report(
-                AVERAGE_NUMBER_OF_TASKS_PER_USER_WHO_HAS_TASKS_AT_ALL,
-                Float.toString(numberOfTasks / numberOfUsers));
+            Datamining.report(AVERAGE_NUMBER_OF_TASKS_PER_USER_WHO_HAS_TASKS_AT_ALL, Float.toString(numberOfTasks / numberOfUsers));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -544,10 +568,9 @@ public class Questions {
             float numberOfDocuments = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_DOCUMENTS));
             float numberOfUsers = Float.valueOf(Datamining.getOneAnswer(NUMBER_OF_USERS_WHO_CREATED_DOCUMENTS));
 
-            Datamining.report(
-                AVERAGE_NUMBER_OF_DOCUMENTS_PER_USER_WHO_HAS_DOCUMENTS_AT_ALL,
-                Float.toString(numberOfDocuments / numberOfUsers));
+            Datamining.report(AVERAGE_NUMBER_OF_DOCUMENTS_PER_USER_WHO_HAS_DOCUMENTS_AT_ALL, Float.toString(numberOfDocuments / numberOfUsers));
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -558,6 +581,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WITH_LINKED_SOCIAL_NETWORKING_ACCOUNTS, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -568,6 +592,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_TEAM_VIEW_AS_CALENDAR_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -578,6 +603,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_CALENDAR_VIEW_AS_CALENDAR_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -588,6 +614,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_LIST_VIEW_AS_CALENDAR_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -598,6 +625,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_CARDS_VIEW_AS_CONTACTS_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -608,6 +636,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_LIST_VIEW_AS_CONTACTS_DEFAULT2, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -618,6 +647,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_LIST_VIEW_AS_TASKS_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -628,6 +658,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_H_SPLIT_VIEW_AS_CONTACTS_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -638,6 +669,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_LIST_VIEW_AS_INFOSTORE_DEFAULT, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -648,6 +680,7 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_SELECTED_LIST_VIEW_AS_CONTACTS_DEFAULT2, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -658,105 +691,115 @@ public class Questions {
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_ACTIVATED_MINI_CALENDAR, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToLinkedIn() {
-    	String networkName = "linkedin";
+        String networkName = "linkedin";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_LINKEDIN);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_LINKEDIN, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToTwitter() {
-    	String networkName = "twitter";
+        String networkName = "twitter";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_TWITTER);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_TWITTER, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToGoogle() {
-    	String networkName = "google";
+        String networkName = "google";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_GOOGLE);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_GOOGLE, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToMSN() {
-    	String networkName = "msn";
+        String networkName = "msn";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_MSN);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_MSN, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToYahoo() {
-    	String networkName = "yahoo";
+        String networkName = "yahoo";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_YAHOO);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_YAHOO, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToXing() {
-    	String networkName = "xing";
+        String networkName = "xing";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_XING);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_XING, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToTOnline() {
-    	String networkName = "t-online";
+        String networkName = "t-online";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_TONLINE);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_TONLINE, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToGMX() {
-    	String networkName = "gmx";
+        String networkName = "gmx";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_GMX);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_GMX, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     public static void reportNumberOfUsersConnectedToWebDe() {
-    	String networkName = "web";
+        String networkName = "web";
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_CONNECTED_TO_WEBDE);
             String sql = "SELECT COUNT(*) FROM (SELECT o.user, o.cid FROM oauthAccounts o where o.serviceId LIKE '%" + networkName + "%' UNION SELECT s.user_id, s.cid FROM subscriptions s where s.source_id LIKE '%" + networkName + "%') AS x;";
             BigInteger numberOfInfostoreObjects = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_CONNECTED_TO_WEBDE, numberOfInfostoreObjects.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
@@ -767,76 +810,84 @@ public class Questions {
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WITH_TASKS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoChangedTheirTasksInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_CHANGED_THEIR_TASKS_IN_THE_LAST30_DAYS);
-            String sql = "SELECT count(DISTINCT created_from, cid) FROM task WHERE DATE(FROM_UNIXTIME(SUBSTRING(CAST(last_modified AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT created_from, cid) FROM task WHERE last_modified>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_CHANGED_THEIR_TASKS_IN_THE_LAST30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientOX6UIInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_OX6UI_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.ox.gui.dhtml' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.ox.gui.dhtml' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_OX6UI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientAppSuiteUIInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_APPSUITEUI_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:open-xchange-appsuite' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:open-xchange-appsuite' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_APPSUITEUI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientEASInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_EAS_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:USM-EAS' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:USM-EAS' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_EAS_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientMobileUIInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_MOBILEUI_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.mobileapp' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:com.openexchange.mobileapp' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_MOBILEUI_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientCalDAVInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CALDAV_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CALDAV' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CALDAV' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CALDAV_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 
     protected static void reportNumberOfUsersWhoLoggedInWithClientCardDAVInTheLast30Days() {
         try {
             Datamining.allTheQuestions.add(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CARDDAV_IN_THE_LAST_30_DAYS);
-            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CARDDAV' AND DATE(FROM_UNIXTIME(SUBSTRING(CAST(value AS CHAR) FROM 1 FOR 10))) BETWEEN (NOW() - INTERVAL 30 DAY) AND NOW()";
+            String sql = "SELECT count(DISTINCT id, cid) FROM user_attribute WHERE name = 'client:CARDDAV' AND value>=" + Tools.calculate30DaysBack() + ";";
             BigInteger numberOfUsers = Datamining.countOverAllSchemata(sql);
             Datamining.report(NUMBER_OF_USERS_WHO_LOGGED_IN_WITH_CLIENT_CARDDAV_IN_THE_LAST_30_DAYS, numberOfUsers.toString());
         } catch (Exception e) {
+            handleError(e);
         }
     }
 }
